# LangGraph on OCI
This repository will contain all the code for the oci_langraph package. A set of utility classes, with usage examples, that will simplify the creation of Enterprise-grade AI agents and workflow on OCI.

## Features available
* **Checkpointing** integrated with LangGraph
* Integration with **OCI APM**
* Classes to simplify integration with **OCI Queue**

## Examples
You can find examples in the directory:
[examples](./examples/)

## Debugging
You can run in DEBUG mode setting the environment variable:
```
DEBUG=True
```





